webbpsf\_ext.webbpsf\_ext\_core
===============================

.. automodule:: webbpsf_ext.webbpsf_ext_core

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      coron_grid
      nrc_mask_trans
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      MIRI_ext
      NIRCam_ext
   
   

   
   
   



